@@ -10,6 +10,11 @@ xml_type <- function(x) {
   UseMethod("xml_type")
 }
 
+#' @export
+xml_type.xml_missing <- function(x) {
+  NA_character_
+}
+
 #' @export
 xml_type.xml_node <- function(x) {
   xmlElementType[node_type(x$node)]
