@@ -16,6 +16,11 @@ xml_url <- function(x) {
   UseMethod("xml_url")
 }
 
+#' @export
+xml_url.xml_missing <- function(x) {
+  NA_character_
+}
+
 #' @export
 xml_url.xml_node <- function(x) {
   doc_url(x$doc)
