@@ -5,11 +5,15 @@
 #include <libxml/tree.h>
 #include <Rcpp.h>
 
-inline void finaliseNode(xmlNode* node) {
+inline void finaliseNode(xmlNodePtr node) {
+  // do nothing
+}
+
+inline void finaliseNs(xmlNsPtr ns) {
   // do nothing
 }
 
 typedef Rcpp::XPtr<xmlDoc,Rcpp::PreserveStorage,xmlFreeDoc> XPtrDoc;
 typedef Rcpp::XPtr<xmlNode,Rcpp::PreserveStorage,finaliseNode> XPtrNode;
-
+typedef Rcpp::XPtr<xmlNs,Rcpp::PreserveStorage,finaliseNs> XPtrNs;
 #endif
